==> lightr_1.5.0.tar.gz: lightr/tests/testthat/_snaps/metadata.md <==
# get_metadata all

    {
      "type": "list",
      "attributes": {
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["name", "user", "date", "spec_model", "spec_ID", "white_inttime", "dark_inttime", "sample_inttime", "white_avgs", "dark_avgs", "sample_avgs", "white_boxcar", "dark_boxcar", "sample_boxcar"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5, 6, 7, 8, 9]
        },
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["data.frame"]
        }
      },
      "value": [
        {
          "type": "character",
          "attributes": {},
          "value": ["OceanOptics_period", "avantes2", "avantes_export", "avantes_export2", "avantes_export_long", "avantes_reflect", "avantes_trans", "irrad", "jazspec"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["hugo", null, null, null, null, null, null, "jaz", "jaz"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": [null, null, null, null, null, null, null, "2013-09-16", "2011-08-29"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": [null, null, null, null, null, null, null, null, null]
        },
        {
          "type": "character",
          "attributes": {},
          "value": [null, "1305084U1", "0804016U1", "1305084U1", "1305084U1", "1305084U1", "0804016U1", "JAZA2517", "JAZA1479"]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [400, 150, 100, 95, 150, 95, 100, 495, 24]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [400, 150, 100, 95, 150, 95, 100, 495, 24]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [400, 150, 100, 95, 150, 95, 100, 495, 24]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [5, 10, 20, 20, 10, 20, 20, 3, 1]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [5, 10, 20, 20, 10, 20, 20, 3, 1]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [5, 10, 20, 20, 10, 20, 20, 3, 1]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [0, 1, 0, 1, 1, 1, 0, 5, 0]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [0, 1, 0, 1, 1, 1, 0, 5, 0]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [0, 1, 0, 1, 1, 1, 0, 5, 0]
        }
      ]
    }

# get_metadata recursive

    {
      "type": "list",
      "attributes": {
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["name", "user", "date", "spec_model", "spec_ID", "white_inttime", "dark_inttime", "sample_inttime", "white_avgs", "dark_avgs", "sample_avgs", "white_boxcar", "dark_boxcar", "sample_boxcar"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5]
        },
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["data.frame"]
        }
      },
      "value": [
        {
          "type": "character",
          "attributes": {},
          "value": ["BB_PF21_4", "OceanOptics_Linux", "OceanOptics_Windows", "OceanOptics_badencode", "whiteref"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["Adminlocal", "hugo", "doutrelant", "user", "gomez"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["2006-06-23", "2016-03-16", "2015-12-04", "2016-12-02", "2018-08-02"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["USB4000", "USB4000", "JazUSB", "USB2000Plus", "USB4000"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["USB4C00008", "USB4C00008", "JAZA2982", "USB2+H06330", "USB4C00008"]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 200, 60, 20, 500]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 200, 60, 20, 500]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 200, 60, 20, 500]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [40, 5, 15, 100, 5]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [40, 5, 15, 100, 5]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [40, 5, 15, 100, 5]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 0, 0, 5, 0]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 0, 0, 5, 0]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 0, 0, 5, 0]
        }
      ]
    }

==> lightr_1.7.0.tar.gz: lightr/tests/testthat/_snaps/metadata.md <==
# get_metadata all

    {
      "type": "list",
      "attributes": {
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["name", "user", "datetime", "spec_model", "spec_ID", "white_inttime", "dark_inttime", "sample_inttime", "white_avgs", "dark_avgs", "sample_avgs", "white_boxcar", "dark_boxcar", "sample_boxcar"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5, 6, 7, 8, 9]
        },
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["data.frame"]
        }
      },
      "value": [
        {
          "type": "character",
          "attributes": {},
          "value": ["OceanOptics_period", "avantes2", "avantes_export", "avantes_export2", "avantes_export_long", "avantes_reflect", "avantes_trans", "irrad", "jazspec"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["hugo", null, null, null, null, null, null, "jaz", "jaz"]
        },
        {
          "type": "double",
          "attributes": {
            "class": {
              "type": "character",
              "attributes": {},
              "value": ["POSIXct", "POSIXt"]
            },
            "tzone": {
              "type": "character",
              "attributes": {},
              "value": ["UTC"]
            }
          },
          "value": ["NA", "NA", "NA", "NA", "NA", "NA", "NA", 1379297743, 1314634993]
        },
        {
          "type": "character",
          "attributes": {},
          "value": [null, null, null, null, null, null, null, null, null]
        },
        {
          "type": "character",
          "attributes": {},
          "value": [null, "1305084U1", "0804016U1", "1305084U1", "1305084U1", "1305084U1", "0804016U1", "JAZA2517", "JAZA1479"]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [400, 150, 100, 95, 150, 95, 100, 495, 24]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [400, 150, 100, 95, 150, 95, 100, 495, 24]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [400, 150, 100, 95, 150, 95, 100, 495, 24]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [5, 10, 20, 20, 10, 20, 20, 3, 1]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [5, 10, 20, 20, 10, 20, 20, 3, 1]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [5, 10, 20, 20, 10, 20, 20, 3, 1]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [0, 1, 0, 1, 1, 1, 0, 5, 0]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [0, 1, 0, 1, 1, 1, 0, 5, 0]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [0, 1, 0, 1, 1, 1, 0, 5, 0]
        }
      ]
    }

# get_metadata recursive

    {
      "type": "list",
      "attributes": {
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["name", "user", "datetime", "spec_model", "spec_ID", "white_inttime", "dark_inttime", "sample_inttime", "white_avgs", "dark_avgs", "sample_avgs", "white_boxcar", "dark_boxcar", "sample_boxcar"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5]
        },
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["data.frame"]
        }
      },
      "value": [
        {
          "type": "character",
          "attributes": {},
          "value": ["BB_PF21_4", "OceanOptics_Linux", "OceanOptics_Windows", "OceanOptics_badencode", "whiteref"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["Adminlocal", "hugo", "doutrelant", "user", "gomez"]
        },
        {
          "type": "double",
          "attributes": {
            "class": {
              "type": "character",
              "attributes": {},
              "value": ["POSIXct", "POSIXt"]
            },
            "tzone": {
              "type": "character",
              "attributes": {},
              "value": ["UTC"]
            }
          },
          "value": [1151055549, 1458134311, 1449224954, 1480711152, 1533225379]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["USB4000", "USB4000", "JazUSB", "USB2000Plus", "USB4000"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["USB4C00008", "USB4C00008", "JAZA2982", "USB2+H06330", "USB4C00008"]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 200, 60, 20, 500]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 200, 60, 20, 500]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 200, 60, 20, 500]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [40, 5, 15, 100, 5]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [40, 5, 15, 100, 5]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [40, 5, 15, 100, 5]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 0, 0, 5, 0]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 0, 0, 5, 0]
        },
        {
          "type": "double",
          "attributes": {},
          "value": [10, 0, 0, 5, 0]
        }
      ]
    }
